==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/FileDetailDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef FILEDETAILDLG_H
#define FILEDETAILDLG_H 1

#include <wx/dialog.h>                      // Needed for wxDialog
#include <wx/timer.h>                       // Needed for wxTimerEvent

#include "resource.h"                       // Needed for IDD_FILEDETAILS

class CPartFile;

class CFileDetailDialog : public wxDialog
{
  //DECLARE_DYNAMIC(CFileDetailDialog)

public:
	CFileDetailDialog(wxWindow* parent,CPartFile* file);   // standard constructor
	virtual ~CFileDetailDialog();
	//virtual BOOL OnInitDialog();
	void Localize();
// Dialog Data
	enum { IDD = IDD_FILEDETAILS };

protected:
	void OnTimer(wxTimerEvent& evt);
#if 0
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	void OnTimer(UINT nIDEvent);
	void OnDestroy();
	DECLARE_MESSAGE_MAP()

	static int CALLBACK CompareListNameItems(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);	// Tarod [Juanjo]
#endif
	DECLARE_EVENT_TABLE()

private:
	void UpdateData();
	CPartFile* m_file;
	//uint32 m_timer;
	wxTimer m_timer;
	void OnClosewnd(wxCommandEvent& evt);
	//afx_msg void OnBnClickedButtonrename();	// Tarod [Juanjo]
	//afx_msg void OnBnClickedButtonStrip();
	//afx_msg void TakeOver();
	void FillSourcenameList();

	void OnBnClickedButtonrename(wxEvent& evt);
	void OnBnClickedButtonStrip(wxEvent& evt);
	void OnBnClickedFileinfo(wxEvent& evt);
	void OnBnClickedShowComment(wxEvent& evt);//for Comment//
	void TakeOver(wxEvent& evt);
	void Rename(wxEvent& evt);

};
#endif

==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/FileDetailDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef FILEDETAILDLG_H
#define FILEDETAILDLG_H 1

#include <wx/dialog.h>                      // Needed for wxDialog
#include <wx/timer.h>                       // Needed for wxTimerEvent

#include "resource.h"                       // Needed for IDD_FILEDETAILS

class CPartFile;

class CFileDetailDialog : public wxDialog
{

public:
        CFileDetailDialog(wxWindow* parent,CPartFile* file);   // standard constructor
        virtual ~CFileDetailDialog();
        void Localize();
// Dialog Data
        enum { IDD = IDD_FILEDETAILS };

protected:
        void OnTimer(wxTimerEvent& evt);
        DECLARE_EVENT_TABLE()

private:
        void UpdateData();
        CPartFile* m_file;
        wxTimer m_timer;
        void OnClosewnd(wxCommandEvent& evt);
        void FillSourcenameList();

        void OnBnClickedButtonrename(wxCommandEvent& evt);
        void OnBnClickedButtonStrip(wxCommandEvent& evt);
        void OnBnClickedFileinfo(wxCommandEvent& evt);
        void OnBnClickedShowComment(wxCommandEvent& evt);//for Comment//
        void TakeOver(wxCommandEvent& evt);
        void Rename(wxCommandEvent& evt);

};

#endif
